import pytest
from pyexcuses import pyexcuses
from pyexcuses.exc import SpokenLanguageNotFoundError
from pyexcuses.exc import ProgrammingLanguageNotFoundError


def test_suggest_solution_default():
    """
    Verify that suggest_solution() returns a non-empty string.
    """
    actual = (
        pyexcuses.suggest_solution()
    )  # get the actual return value of suggest_solution()
    assert isinstance(
        actual, str
    ), f"Expected suggest_solution() to return a string. Instead, it returned {actual}"
    assert (
        len(actual) > 0
    ), f"Expected suggest_solution() not to be empty. Instead, it returned a string with {len(actual)} characters"


def test_suggest_solution_spanish():
    """
    Verify that suggest_solution() returns a non-empty string in spanish mode.
    """
    actual = pyexcuses.suggest_solution(
        spoken_language="es"
    )  # get the actual return value of suggest_solution()
    assert isinstance(
        actual, str
    ), f"Expected suggest_solution() to return a string. Instead, it returned {actual}"
    assert (
        len(actual) > 0
    ), f"Expected suggest_solution() not to be empty. Instead, it returned a string with {len(actual)} characters"


def test_suggest_solution_invalid_spokenlanguage():
    """
    Verify that suggest_solution() will fail if given a fake spoken language.
    """
    with pytest.raises(SpokenLanguageNotFoundError) as exception:
        pyexcuses.suggest_solution(spoken_language="no")
    assert isinstance(
        exception.value, SpokenLanguageNotFoundError
    ), f"Expected suggest_solution() to return an error. Instead, it returned {type(exception.value)}"


def test_suggest_solution_invalid_programminglanguage():
    """
    Verify that suggest_solution() will fail if given a fake programming language.
    """
    with pytest.raises(ProgrammingLanguageNotFoundError) as exception:
        pyexcuses.suggest_solution(programming_language="c#")
    assert isinstance(
        exception.value, ProgrammingLanguageNotFoundError
    ), f"Expected suggest_solution() to return an error. Instead, it returned {type(exception.value)}"



import pytest
from pyexcuses import pyexcuses

def test_list_available_options_spoken_language():
    result = pyexcuses.list_available_options("spoken_language")
    assert isinstance(result, list)
    assert "en" in result
    assert "es" in result

def test_list_available_options_programming_language():
    result = pyexcuses.list_available_options("programming_language")
    assert isinstance(result, list)
    assert "neutral" in result
    assert "javascript" in result
    assert "python" in result

def test_list_available_options_invalid_type():
    with pytest.raises(ValueError, match="Invalid option type. Choose either 'spoken_language' or 'programming_language'."):
        pyexcuses.list_available_options("invalid_type")




import pytest
from pyexcuses import pyexcuses

def test_get_multilingual_excuse_or_solution_excuse():
    result = pyexcuses.get_multilingual_excuse_or_solution("excuse", "python")
    assert isinstance(result, dict)
    assert "en" in result and isinstance(result["en"], str)
    assert "es" in result and isinstance(result["es"], str)

def test_get_multilingual_excuse_or_solution_solution():
    result = pyexcuses.get_multilingual_excuse_or_solution("solution", "javascript")
    assert isinstance(result, dict)
    assert "en" in result and isinstance(result["en"], str)
    assert "es" in result and isinstance(result["es"], str)

def test_get_multilingual_excuse_or_solution_invalid_type():
    with pytest.raises(ValueError, match="Invalid option type. Choose either 'excuse' or 'solution'."):
        pyexcuses.get_multilingual_excuse_or_solution("invalid_type", "python")

def test_get_multilingual_excuse_or_solution_unsupported_language():
    # Mock unsupported language by adding exception handling, assuming generate_excuse and suggest_solution will raise the error
    result = pyexcuses.get_multilingual_excuse_or_solution("excuse", "unsupported_language")
    assert result["en"] == "No available option"
    assert result["es"] == "No available option"



import setuptools 

with open("README.md", "r") as fh: 
	long_description = fh.read() 

setuptools.setup( 
	# Here is the module name. 
	name="pyexcuses", 

	# version of the module 
	version="0.0.1", 

	# Name of Author 
	author="Darren Zou, Peter D'Angelo, Gene Park, Joseph Chege", 

	# your Email address 
	author_email="dz2218@nyu.edu", 

	# #Small Description about module 
	# description="adding number", 

	# long_description=long_description, 

	# Specifying that we are using markdown file for description 
	long_description=long_description, 
	long_description_content_type="text/markdown", 

	# Any link to reach this module, ***if*** you have any webpage or github profile 
	# url="https://github.com/username/", 
	packages=setuptools.find_packages(), 


	# if module has dependencies i.e. if your package rely on other package at pypi.org 
	# then you must add there, in order to download every requirement of package 



	#	 install_requires=[ 
	#	 "package1", 
	# "package2", 
	# ], 

	install_requires=['typing'],

	# classifiers like program is suitable for python3, just leave as it is. 
	classifiers=[ 
		"Programming Language :: Python :: 3", 
		"License :: OSI Approved :: NYU License", 
		"Operating System :: OS Independent", 
	], 
) 
